@@ -1,6 +1,6 @@
 package Template::Perlish;
 
-$VERSION = '1.30_02';
+$VERSION = '1.30_03';
 
 use 5.008_000;
 use warnings;
@@ -296,7 +296,7 @@ sub _smart_split {
    # cleanup @path components
    for my $part (@path) {
       my @subparts;
-      while ((pos($part) // 0) < length($part)) {
+      while ((pos($part) || 0) < length($part)) {
          if ($part =~ m{\G ($sq) }cgmxs) {
             push @subparts, substr $1, 1, length($1) - 2;
          }
